<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
<context>
    <name>AccountItem</name>
    <message>
        <location filename="../calendar-client/src/dataManage/accountitem.cpp" line="56"/>
        <source>Sync successful</source>
        <translation>A szinkronizálás sikeres</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dataManage/accountitem.cpp" line="57"/>
        <source>Network error</source>
        <translation>Hálózati hiba</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dataManage/accountitem.cpp" line="58"/>
        <source>Server exception</source>
        <translation>Szerver kivétel</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dataManage/accountitem.cpp" line="59"/>
        <source>Storage full</source>
        <translation>A tárhely megtelt</translation>
    </message>
</context>
<context>
    <name>AccountManager</name>
    <message>
        <location filename="../calendar-client/src/dataManage/accountmanager.cpp" line="225"/>
        <source>Local account</source>
        <translation>Helyi fiók</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dataManage/accountmanager.cpp" line="227"/>
        <source>Event types</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CColorPickerWidget</name>
    <message>
        <location filename="../calendar-client/src/customWidget/colorWidget/colorpickerWidget.cpp" line="91"/>
        <source>Color</source>
        <translation>Szín</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/colorWidget/colorpickerWidget.cpp" line="104"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Mégsem</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/colorWidget/colorpickerWidget.cpp" line="106"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Mentés</translation>
    </message>
</context>
<context>
    <name>CDayMonthView</name>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="48"/>
        <source>Monday</source>
        <translation>Hétfő</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="49"/>
        <source>Tuesday</source>
        <translation>Kedd</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="50"/>
        <source>Wednesday</source>
        <translation>Szerda</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="51"/>
        <source>Thursday</source>
        <translation>Csütörtök</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="52"/>
        <source>Friday</source>
        <translation>Péntek</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="53"/>
        <source>Saturday</source>
        <translation>Szombat</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="54"/>
        <source>Sunday</source>
        <translation>Vasárnap</translation>
    </message>
</context>
<context>
    <name>CDayWindow</name>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daywindow.cpp" line="126"/>
        <source>Y</source>
        <translation>Éves</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daywindow.cpp" line="127"/>
        <source>M</source>
        <translation>Havi</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daywindow.cpp" line="128"/>
        <source>D</source>
        <translation>Napi</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daywindow.cpp" line="184"/>
        <source>Lunar</source>
        <translation>Hold naptár</translation>
    </message>
</context>
<context>
    <name>CGraphicsView</name>
    <message>
        <location filename="../calendar-client/src/view/graphicsview.cpp" line="600"/>
        <source>New Event</source>
        <translation>Új esemény</translation>
    </message>
</context>
<context>
    <name>CMonthScheduleNumItem</name>
    <message>
        <location filename="../calendar-client/src/view/graphicsItem/cmonthschedulenumitem.cpp" line="96"/>
        <source>%1 more</source>
        <translation>%1 továbbiak</translation>
    </message>
</context>
<context>
    <name>CMonthView</name>
    <message>
        <location filename="../calendar-client/src/widget/monthWidget/monthview.cpp" line="65"/>
        <source>New event</source>
        <translation>Új esemény</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/monthWidget/monthview.cpp" line="223"/>
        <source>New Event</source>
        <translation>Új esemény</translation>
    </message>
</context>
<context>
    <name>CMonthWindow</name>
    <message>
        <location filename="../calendar-client/src/widget/monthWidget/monthwindow.cpp" line="112"/>
        <source>Y</source>
        <translation>Év</translation>
    </message>
</context>
<context>
    <name>CMyScheduleView</name>
    <message>
        <location filename="../calendar-client/src/dialog/myscheduleview.cpp" line="289"/>
        <source>My Event</source>
        <translation>Eseményeim</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/myscheduleview.cpp" line="330"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/myscheduleview.cpp" line="334"/>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Törlés</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/myscheduleview.cpp" line="335"/>
        <source>Edit</source>
        <comment>button</comment>
        <translation>Szerkesztés</translation>
    </message>
</context>
<context>
    <name>CPushButton</name>
    <message>
        <location filename="../calendar-client/src/customWidget/cpushbutton.cpp" line="33"/>
        <source>New event type</source>
        <translation>Új esemény típusa</translation>
    </message>
</context>
<context>
    <name>CScheduleDlg</name>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="58"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="612"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="908"/>
        <source>New Event</source>
        <translation>Új esemény</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="71"/>
        <source>Edit Event</source>
        <translation>Esemény szerkesztése</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="269"/>
        <source>End time must be greater than start time</source>
        <translation>A befejezés időpontjának a kezdés időpontjánál későbbre kell esnie</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="270"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="494"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="523"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1120"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1155"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1409"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1413"/>
        <source>Never</source>
        <translation>Soha</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="495"/>
        <source>At time of event</source>
        <translation>Az esemény időpontjában</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="496"/>
        <source>15 minutes before</source>
        <translation>15 perccel előtte</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="497"/>
        <source>30 minutes before</source>
        <translation>30 perccel előtte</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="498"/>
        <source>1 hour before</source>
        <translation>1 órával előtte</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="499"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="525"/>
        <source>1 day before</source>
        <translation>1 nappal előtte</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="500"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="526"/>
        <source>2 days before</source>
        <translation>2 nappal előtte</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="501"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="527"/>
        <source>1 week before</source>
        <translation>1 héttel előtte</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="524"/>
        <source>On start day (9:00 AM)</source>
        <translation>Esemény kezdete napján (De. 09:00)</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="571"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="778"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1176"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1177"/>
        <source>time(s)</source>
        <translation>Időpont(ok)</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="585"/>
        <source>Enter a name please</source>
        <translation>Kérjük adjon meg egy nevet</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="680"/>
        <source>The name can not only contain whitespaces</source>
        <translation>A név nem tartalmazhat csak szóközöket</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="736"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="858"/>
        <source>Type:</source>
        <translation>Típus:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="741"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="893"/>
        <source>Description:</source>
        <translation>Leírás:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="746"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="930"/>
        <source>All Day:</source>
        <translation>Egész nap:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="751"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="996"/>
        <source>Starts:</source>
        <translation>Kezdés:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="756"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1037"/>
        <source>Ends:</source>
        <translation>Befejezés:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="761"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1077"/>
        <source>Remind Me:</source>
        <translation>Emlékeztessen:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="766"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1109"/>
        <source>Repeat:</source>
        <translation>Ismétlés:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="771"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1143"/>
        <source>End Repeat:</source>
        <translation>Ismétlés vége:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="827"/>
        <source>Calendar account:</source>
        <translation>Naptár fiók:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="828"/>
        <source>Calendar account</source>
        <translation>Naptár fiók</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="855"/>
        <source>Type</source>
        <translation>Típus</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="897"/>
        <source>Description</source>
        <translation>Leírás</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="927"/>
        <source>All Day</source>
        <translation>Egész nap</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="951"/>
        <source>Time:</source>
        <translation>Idő:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="952"/>
        <source>Time</source>
        <translation>Idő</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="959"/>
        <source>Solar</source>
        <translation>Nap</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="960"/>
        <source>Lunar</source>
        <translation>Hold</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="993"/>
        <source>Starts</source>
        <translation>Kezdés</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1034"/>
        <source>Ends</source>
        <translation>Befejezés</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1079"/>
        <source>Remind Me</source>
        <translation>Emlékeztessen</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1106"/>
        <source>Repeat</source>
        <translation>Ismétlés</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1121"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1414"/>
        <source>Daily</source>
        <translation>Naponta</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1122"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1415"/>
        <source>Weekdays</source>
        <translation>Hétköznapokon</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1123"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1416"/>
        <source>Weekly</source>
        <translation>Hetente</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1124"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1410"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1417"/>
        <source>Monthly</source>
        <translation>Havonta</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1125"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1411"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1418"/>
        <source>Yearly</source>
        <translation>Évente</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1145"/>
        <source>End Repeat</source>
        <translation>Ismétlés vége</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1156"/>
        <source>After</source>
        <translation>Utána</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1157"/>
        <source>On</source>
        <translation>Ekkor</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1227"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Mégsem</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1228"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Mentés</translation>
    </message>
</context>
<context>
    <name>CScheduleOperation</name>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="94"/>
        <source>All occurrences of a repeating event must have the same all-day status.</source>
        <translation>Az ismétlődő események valamennyiének &quot;egész nap&quot; állapotúnak kell lennie.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="95"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="112"/>
        <source>Do you want to change all occurrences?</source>
        <translation>Minden alkalmat módosítani szeretne?</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="96"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="113"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="143"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="162"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="182"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="254"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="284"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Mégsem</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="97"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="114"/>
        <source>Change All</source>
        <translation>Összes módosítása</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="111"/>
        <source>You are changing the repeating rule of this event.</source>
        <translation>Módosítja az esemény ismétlődési szabályát.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="141"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="160"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="180"/>
        <source>You are deleting an event.</source>
        <translation>Ön töröl egy eseményt.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="142"/>
        <source>Are you sure you want to delete this event?</source>
        <translation>Biztosan törli ezt az eseményt?</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="144"/>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Törlés</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="161"/>
        <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
        <translation>Törlöni szeretné az esemény összes előfordulását, vagy csak a kiválasztott eseményt?</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="163"/>
        <source>Delete All</source>
        <translation>Összes törlése</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="164"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="184"/>
        <source>Delete Only This Event</source>
        <translation>Csak ezen esemény törlése</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="181"/>
        <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
        <translation>Törölni szeretné ezt, és az esemény összes jövőbeli előfordulását, vagy csak a kiválasztott eseményt?</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="183"/>
        <source>Delete All Future Events</source>
        <translation>Összes jövőbeli esemény törlése</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="250"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="280"/>
        <source>You are changing a repeating event.</source>
        <translation>Ön egy ismétlődő eseményt módosít.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="252"/>
        <source>Do you want to change only this occurrence of the event, or all occurrences?</source>
        <translation>Csak az esemény ezen előfordulását akarja megváltoztatni, vagy az összes jövőbeni eseményt?</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="255"/>
        <source>All</source>
        <translation>Összes</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="256"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="286"/>
        <source>Only This Event</source>
        <translation>Csak ezen esemény</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="282"/>
        <source>Do you want to change only this occurrence of the event, or this and all future occurrences?</source>
        <translation>Csak az esemény ezen előfordulását akarja megváltoztatni, vagy ezt és az összes jövőbeni eseményt?</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="285"/>
        <source>All Future Events</source>
        <translation>Összes jövőbeli esemény</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="397"/>
        <source>You have selected a leap month, and will be reminded according to the rules of the lunar calendar.</source>
        <translation>Szökőhónap lett kiválasztva, ezért a holdnaptár szabályai fognak érvényesülni.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="398"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>CScheduleSearchDateItem</name>
    <message>
        <location filename="../calendar-client/src/widget/schedulesearchview.cpp" line="915"/>
        <source>Y</source>
        <translation>Év</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/schedulesearchview.cpp" line="915"/>
        <source>M</source>
        <translation>Hónap</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/schedulesearchview.cpp" line="915"/>
        <source>D</source>
        <translation>Nap</translation>
    </message>
</context>
<context>
    <name>CScheduleSearchItem</name>
    <message>
        <location filename="../calendar-client/src/widget/schedulesearchview.cpp" line="56"/>
        <source>Edit</source>
        <translation>Szerkesztés</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/schedulesearchview.cpp" line="57"/>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/schedulesearchview.cpp" line="281"/>
        <source>All Day</source>
        <translation>Egész nap</translation>
    </message>
</context>
<context>
    <name>CScheduleSearchView</name>
    <message>
        <location filename="../calendar-client/src/widget/schedulesearchview.cpp" line="658"/>
        <source>No search results</source>
        <translation>Nincs keresési eredmény</translation>
    </message>
</context>
<context>
    <name>CScheduleView</name>
    <message>
        <location filename="../calendar-client/src/customWidget/scheduleview.cpp" line="327"/>
        <source>ALL DAY</source>
        <translation>Egész nap</translation>
    </message>
</context>
<context>
    <name>CSettingDialog</name>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="351"/>
        <source>Sunday</source>
        <translation>Vasárnap</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="352"/>
        <source>Monday</source>
        <translation>Hétfő</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="369"/>
        <source>24-hour clock</source>
        <translation>24 órás óra formátum</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="370"/>
        <source>12-hour clock</source>
        <translation>12 órás óra formátum</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="403"/>
        <source>Manual</source>
        <translation>Manuális</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="404"/>
        <source>15 mins</source>
        <translation>15 perc</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="405"/>
        <source>30 mins</source>
        <translation>30 perc</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="406"/>
        <source>1 hour</source>
        <translation>1 óra</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="407"/>
        <source>24 hours</source>
        <translation>24 óra</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="418"/>
        <source>Sync Now</source>
        <translation>Szinkronizálás most</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="561"/>
        <source>Last sync</source>
        <translation>Utolsó szinkronizálás</translation>
    </message>
</context>
<context>
    <name>CTimeEdit</name>
    <message>
        <location filename="../calendar-client/src/customWidget/timeedit.cpp" line="86"/>
        <source>(%1 mins)</source>
        <translation>(%1 perc)</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/timeedit.cpp" line="88"/>
        <source>(%1 hour)</source>
        <translation>(%1 óra)</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/timeedit.cpp" line="90"/>
        <source>(%1 hours)</source>
        <translation>(%1 óra)</translation>
    </message>
</context>
<context>
    <name>CTitleWidget</name>
    <message>
        <location filename="../calendar-client/src/customWidget/ctitlewidget.cpp" line="46"/>
        <source>Y</source>
        <translation>Év</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/ctitlewidget.cpp" line="58"/>
        <source>M</source>
        <translation>Hó</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/ctitlewidget.cpp" line="66"/>
        <source>W</source>
        <translation>Hét</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/ctitlewidget.cpp" line="74"/>
        <source>D</source>
        <translation>Nap</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/ctitlewidget.cpp" line="108"/>
        <location filename="../calendar-client/src/customWidget/ctitlewidget.cpp" line="109"/>
        <source>Search events and festivals</source>
        <translation>Események és fesztiválok keresése</translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <location filename="../calendar-client/src/customWidget/cweekwidget.cpp" line="88"/>
        <source>Sun</source>
        <translation>V.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/cweekwidget.cpp" line="88"/>
        <source>Mon</source>
        <translation>H.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/cweekwidget.cpp" line="88"/>
        <source>Tue</source>
        <translation>K.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/cweekwidget.cpp" line="88"/>
        <source>Wed</source>
        <translation>Sze.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/cweekwidget.cpp" line="88"/>
        <source>Thu</source>
        <translation>Cs.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/cweekwidget.cpp" line="88"/>
        <source>Fri</source>
        <translation>P.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/cweekwidget.cpp" line="88"/>
        <source>Sat</source>
        <translation>Szo.</translation>
    </message>
</context>
<context>
    <name>CWeekWindow</name>
    <message>
        <location filename="../calendar-client/src/widget/weekWidget/weekwindow.cpp" line="102"/>
        <source>Week</source>
        <translation>Hét</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/weekWidget/weekwindow.cpp" line="289"/>
        <source>Y</source>
        <translation>Év</translation>
    </message>
</context>
<context>
    <name>CYearScheduleView</name>
    <message>
        <location filename="../calendar-client/src/widget/yearWidget/yearscheduleview.cpp" line="278"/>
        <location filename="../calendar-client/src/widget/yearWidget/yearscheduleview.cpp" line="281"/>
        <source>All Day</source>
        <translation>Egész nap</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/yearWidget/yearscheduleview.cpp" line="298"/>
        <source>No event</source>
        <translation>Nincs esemény</translation>
    </message>
</context>
<context>
    <name>CYearWindow</name>
    <message>
        <location filename="../calendar-client/src/widget/yearWidget/yearwindow.cpp" line="632"/>
        <source>Y</source>
        <translation>Év</translation>
    </message>
</context>
<context>
    <name>CalendarWindow</name>
    <message>
        <location filename="../calendar-client/src/main.cpp" line="68"/>
        <source>Calendar</source>
        <translation>Naptár</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/main.cpp" line="71"/>
        <source>Calendar is a tool to view dates, and also a smart daily planner to schedule all things in life. </source>
        <translation>A Naptár egy eszköz a dátumok megtekintésére, valamint egy intelligens napi tervező az élet minden dolgának ütemezéséhez.</translation>
    </message>
</context>
<context>
    <name>Calendarmainwindow</name>
    <message>
        <location filename="../calendar-client/src/widget/calendarmainwindow.cpp" line="100"/>
        <source>Calendar</source>
        <translation>Naptár</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/calendarmainwindow.cpp" line="369"/>
        <source>Manage</source>
        <translation>Kezelés</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/calendarmainwindow.cpp" line="376"/>
        <source>Privacy Policy</source>
        <translation>Adatvédelmi irányelvek</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/calendarmainwindow.cpp" line="941"/>
        <source>Syncing...</source>
        <translation>Szinkronizálás...</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/calendarmainwindow.cpp" line="950"/>
        <source>Sync successful</source>
        <translation>A szinkronizálás sikeres</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/calendarmainwindow.cpp" line="956"/>
        <source>Sync failed, please try later</source>
        <translation>A szinkronizálás sikertelen, kérjük próbálja később</translation>
    </message>
</context>
<context>
    <name>CenterWidget</name>
    <message>
        <location filename="../calendar-client/src/customWidget/scheduleRemindWidget.cpp" line="190"/>
        <source>All Day</source>
        <translation>Egész nap</translation>
    </message>
</context>
<context>
    <name>DragInfoGraphicsView</name>
    <message>
        <location filename="../calendar-client/src/view/draginfographicsview.cpp" line="63"/>
        <source>Edit</source>
        <translation>Szerkesztés</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/view/draginfographicsview.cpp" line="64"/>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/view/draginfographicsview.cpp" line="65"/>
        <source>New event</source>
        <translation>Új esemény</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/view/draginfographicsview.cpp" line="749"/>
        <source>New Event</source>
        <translation>Új esemény</translation>
    </message>
</context>
<context>
    <name>JobTypeListView</name>
    <message>
        <location filename="../calendar-client/src/customWidget/jobtypelistview.cpp" line="267"/>
        <source>You are deleting an event type.</source>
        <translation>Ön töröl egy eseménytípust.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/jobtypelistview.cpp" line="268"/>
        <source>All events under this type will be deleted and cannot be recovered.</source>
        <translation>Az összes ilyen típusú esemény törlődik, és nem állítható helyre.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/jobtypelistview.cpp" line="269"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Mégsem</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/jobtypelistview.cpp" line="270"/>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Törlés</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="103"/>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="134"/>
        <source>Manage calendar</source>
        <translation>Naptár kezelése</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="119"/>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="138"/>
        <source>Event types</source>
        <translation>Esemény típusok</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="45"/>
        <source>Account settings</source>
        <translation>Felhasználói fiók beállítások</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="49"/>
        <source>Account</source>
        <translation>Felhasználói fiók</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="60"/>
        <source>Select items to be synced</source>
        <translation>Válassza ki a szinkronizálni kívánt elemeket</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="63"/>
        <source>Events</source>
        <translation>Események</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="70"/>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="153"/>
        <source>General settings</source>
        <translation>Általános beállítások</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="81"/>
        <source>Sync interval</source>
        <translation>Szinkronizálási időintervallum</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="111"/>
        <source>Calendar account</source>
        <translation>Naptár fiók</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="157"/>
        <source>General</source>
        <translation>Általános</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="161"/>
        <source>First day of week</source>
        <translation>A hét első napja</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="169"/>
        <source>Time</source>
        <translation>Idő</translation>
    </message>
</context>
<context>
    <name>Return</name>
    <message>
        <location filename="../calendar-client/src/widget/yearWidget/yearwindow.cpp" line="628"/>
        <source>Today</source>
        <comment>Return</comment>
        <translation>Ma</translation>
    </message>
</context>
<context>
    <name>Return Today</name>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="356"/>
        <location filename="../calendar-client/src/widget/monthWidget/monthwindow.cpp" line="109"/>
        <location filename="../calendar-client/src/widget/weekWidget/weekwindow.cpp" line="286"/>
        <source>Today</source>
        <comment>Return Today</comment>
        <translation>Ma</translation>
    </message>
</context>
<context>
    <name>ScheduleTypeEditDlg</name>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="36"/>
        <source>New event type</source>
        <translation>Új esemény típusa</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="46"/>
        <source>Edit event type</source>
        <translation>Eseménytípus szerkesztése</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="133"/>
        <source>Name:</source>
        <translation>Név:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="143"/>
        <source>Color:</source>
        <translation>Szín:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="171"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Mégsem</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="172"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Mentés</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="221"/>
        <source>The name can not only contain whitespaces</source>
        <translation>A név nem tartalmazhat csak szóközöket</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="281"/>
        <source>Enter a name please</source>
        <translation>Kérjük adjon meg egy nevet</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <location filename="../calendar-client/src/shortcut.cpp" line="31"/>
        <source>Help</source>
        <translation>Segítség</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/shortcut.cpp" line="32"/>
        <source>Delete event</source>
        <translation>Esemény törlése</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/shortcut.cpp" line="35"/>
        <source>Copy</source>
        <translation>Másolás</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/shortcut.cpp" line="36"/>
        <source>Cut</source>
        <translation>Kivágás</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/shortcut.cpp" line="37"/>
        <source>Paste</source>
        <translation>Beillesztés</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/shortcut.cpp" line="40"/>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/shortcut.cpp" line="41"/>
        <source>Select all</source>
        <translation>Összes kijelölése</translation>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <location filename="../calendar-client/src/widget/sidebarWidget/sidebarcalendarwidget.cpp" line="142"/>
        <source>Y</source>
        <translation>Éves</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/sidebarWidget/sidebarcalendarwidget.cpp" line="142"/>
        <source>M</source>
        <translation>Havi</translation>
    </message>
</context>
<context>
    <name>TimeJumpDialog</name>
    <message>
        <location filename="../calendar-client/src/dialog/timejumpdialog.cpp" line="45"/>
        <source>Go</source>
        <comment>button</comment>
        <translation>Ugrás</translation>
    </message>
</context>
<context>
    <name>UserloginWidget</name>
    <message>
        <location filename="../calendar-client/src/widget/settingWidget/userloginwidget.cpp" line="63"/>
        <source>Sign In</source>
        <comment>button</comment>
        <translation>Bejelentkezés</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/settingWidget/userloginwidget.cpp" line="64"/>
        <source>Sign Out</source>
        <comment>button</comment>
        <translation>Kijelentkezés</translation>
    </message>
</context>
<context>
    <name>YearFrame</name>
    <message>
        <location filename="../calendar-client/src/widget/yearWidget/yearwindow.cpp" line="941"/>
        <source>Y</source>
        <translation>Év</translation>
    </message>
</context>
<context>
    <name>today</name>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="203"/>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="354"/>
        <location filename="../calendar-client/src/widget/monthWidget/monthwindow.cpp" line="107"/>
        <location filename="../calendar-client/src/widget/monthWidget/monthwindow.cpp" line="244"/>
        <location filename="../calendar-client/src/widget/weekWidget/weekwindow.cpp" line="69"/>
        <location filename="../calendar-client/src/widget/weekWidget/weekwindow.cpp" line="284"/>
        <location filename="../calendar-client/src/widget/yearWidget/yearwindow.cpp" line="278"/>
        <location filename="../calendar-client/src/widget/yearWidget/yearwindow.cpp" line="626"/>
        <source>Today</source>
        <comment>Today</comment>
        <translation>Ma</translation>
    </message>
</context>
</TS>